Documentation
¶
Index ¶
- func Fprint(w io.Writer, node interface{}) error
- type ArrayLit
- type BlockStmt
- type CaseLabel
- type Catch
- type ClassDecl
- type ClassMemberDecl
- type CommentStmt
- type ConstDecl
- type Decl
- type Expr
- type File
- type ForStmt
- type FuncDecl
- type FuncLit
- type IfStmt
- type InterfaceDecl
- type Member
- type Name
- type Param
- type Pragma
- type StaticSelectorExpr
- type Stmt
- type SwitchStmt
- type SyntaxError
- type TraitDecl
- type TryStmt
- type Type
- type UnknownExpr
- type UnknownStmt
- type UseStmt
- type VarDecl
- type Vis
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ClassDecl ¶
type ClassMemberDecl ¶
type ConstDecl ¶
type Decl ¶
type Decl interface {
// contains filtered or unexported methods
}
type Expr ¶
type Expr interface{}
type File ¶
type ForStmt ¶
type FuncDecl ¶
type FuncLit ¶
type InterfaceDecl ¶
type Member ¶
type Member interface{}
type Name ¶
A Name represents a (possibly qualified or fully qualified) PHP name, which might be a class name, a built-in type, or a special value type (e.g. null, false).
type Param ¶
type Stmt ¶
type Stmt interface{}
type SyntaxError ¶
SyntaxError records an error and the position it occured on.
func (*SyntaxError) Error ¶
func (e *SyntaxError) Error() string
type UnknownExpr ¶
type UnknownExpr struct {
Elems []interface{}
}
type UnknownStmt ¶
type VarDecl ¶
Source Files
¶
- ast.go
- parse.go
- print.go
Click to show internal directories.
Click to hide internal directories.